@@ -23,6 +23,7 @@ from sphinx.util.osutil import copyfile, ensuredir
 from uqbar.book.extensions import Extension
 from uqbar.strings import normalize
 
+from .. import format as _format
 from .. import lilypondfile as _lilypondfile
 from .. import tag as _tag
 from ..configuration import Configuration
@@ -264,6 +265,7 @@ class LilyPondExtension(Extension):
             illustration["score"].items.append(block)
         illustration.lilypond_version_token = r'\version "2.19.83"'
         code = illustration._get_lilypond_format()
+        code = _format.remove_site_comments(code)
         code = _tag.remove_tags(code)
         node = self.lilypond_block(code, code)
         node["kind"] = self.kind.name.lower()
